@@ -1530,6 +1530,7 @@ def Tabla_Estadistica_Error(y11,y12,y21,y22,y31,y32,y41,y42):
     return tabla
 
 
+##################### PARTE 3 #########################
 ##################### PARTE 3 #########################
 
 def InsertColumnasAVM(reavm):
@@ -1548,28 +1549,6 @@ def Is_estimated_by_AVM(reavm):
     print(f"Cuyo porcentaje equivale a: {(len(reavm[reavm['Estimación AVM']>0])*100)/reavm.shape[0]: .2f}%")
     return reavm1,reavm2
 
-def add_index_AVM(reml,reml2,index_maximos):
-    L_5=list(reml['Index_antiguedad_5'].unique())
-    L_5.sort()
-    L_10=list(reml["Index_antiguedad_10"].unique())
-    L_10.sort()
-    nombre1="Index_antiguedad_5"
-    nombre2="Index_antiguedad_10" 
-    for i in range(0,len(index_maximos[0])): 
-        if index_maximos[0][i] not in L_10:
-            string=nombre2+"_"+index_maximos[0][i]
-            reml.insert(i+25, string, 0, allow_duplicates=False)
-        elif index_maximos[0][i] in L_10:
-            string=nombre2+"_"+index_maximos[0][i]
-            reml.insert(i+25,string,np.array(reml2[[string]]))
-    for j in range(0,len(index_maximos[1])):
-        if index_maximos[1][j] not in L_5:
-            string=nombre1+"_"+index_maximos[1][j]
-            reml.insert(j+25+len(index_maximos[0]), string, 0, allow_duplicates=False)
-        elif index_maximos[1][j] in L_5:
-            string=nombre1+"_"+index_maximos[1][j]
-            reml.insert(j+25+len(index_maximos[0]),string,np.array(reml2[[string]]))
-    return reml
 
 def Rend_Est_AVM(reavm2):
     plt.rcParams['figure.figsize'] = (9,5);
@@ -1585,11 +1564,52 @@ def Rend_Est_AVM(reavm2):
     plt.ylabel('Valor Estimado AVM');
     plt.grid(True)
     plt.show()
-    
-    
-def Xrl_inter(reml,reml2,inter):
-    Xrlinter = np.array(reml2[indexs(inter,reml)])
-    long=len(indexs(inter,reml))
+
+def add_index_AVM(reml,reml2,index_maximos):
+    L_5=list(reml['Index_antiguedad_5'].unique())
+    L_5.sort()
+    L_10=list(reml["Index_antiguedad_10"].unique())
+    L_10.sort()
+    remL=reml.copy()
+    nombre1="Index_antiguedad_5"
+    nombre2="Index_antiguedad_10" 
+    for i in range(0,len(index_maximos[0])): 
+        if index_maximos[0][i] not in L_10:
+            string=nombre2+"_"+index_maximos[0][i]
+            remL.insert(i+25, string, 0, allow_duplicates=False)
+        elif index_maximos[0][i] in L_10:
+            string=nombre2+"_"+index_maximos[0][i]
+            remL.insert(i+25,string,np.array(reml2[[string]]))
+    for j in range(0,len(index_maximos[1])):
+        if index_maximos[1][j] not in L_5:
+            string=nombre1+"_"+index_maximos[1][j]
+            remL.insert(j+25+len(index_maximos[0]), string, 0, allow_duplicates=False)
+        elif index_maximos[1][j] in L_5:
+            string=nombre1+"_"+index_maximos[1][j]
+            remL.insert(j+25+len(index_maximos[0]),string,np.array(reml2[[string]]))
+    return remL
+
+def Xrl_inter(remL,inter,indexs_max):
+    if inter==1:
+        indexaciones=['antiguedad','longitud','latitud','supCSII','supTSII']
+        Xrlinter = np.array(remL[indexaciones])
+        long=len(indexaciones)
+    elif inter==10:
+        indexaciones=['longitud', 'latitud', 'supCSII', 'supTSII']
+        for j in range(0,len(indexs_max[0])):
+            ins=str(indexs_max[0][j])
+            string="Index_antiguedad_10_"+ins
+            indexaciones.insert(j,string)
+        Xrlinter = np.array(remL[indexaciones])
+        long=len(indexaciones)
+    elif inter==5:
+        indexaciones=['longitud', 'latitud', 'supCSII', 'supTSII']
+        for j in range(0,len(indexs_max[1])):
+            ins=str(indexs_max[1][j])
+            string="Index_antiguedad_5_"+ins
+            indexaciones.insert(j,string)
+        Xrlinter = np.array(remL[indexaciones])
+        long=len(indexaciones)
     return Xrlinter,long
 
 
